@@ -1,5 +1,8 @@
 import json
+import os
 import os.path as osp
+import re
+import sys
 
 
 class MapperOption:
@@ -21,13 +24,26 @@ class MapperOption:
 class BaseEndpointMapper:
     @staticmethod
     def config() -> MapperOption:
-        base_dir = osp.dirname(osp.abspath(__file__))
-        config_path = osp.join(base_dir, "emapcfg.json")
+        cfg_name = 'emapcfg.json'
+        cfg_path = None
 
-        if osp.exists(config_path):
-            with open("emapcfg.json", "r") as fp:
+        for p in sys.path:
+            path = f"{p}/{cfg_name}"
+            if osp.exists(path):
+                cfg_path = path
+                break
+
+        if cfg_path:
+            with open(cfg_path, "r") as fp:
                 obj = json.load(fp)
-                print(obj)
+
+            services = obj.get('services')
+            if services:
+                for key, service in services.items():
+                    if service.startswith('$'):
+                        env_name = re.search(r"\$\{(.*)}", service).group(1)
+                        services[key] = os.environ.get(env_name, None)
+
             return MapperOption(
                 path_white_list=obj.get('path_white_list'),
                 path_black_list=obj.get('path_black_list'),
